SystemOrganization addCategory: #'Generic-Spreadsheet'!

Object subclass: #GenericCell
	instanceVariableNames: 'cellValue cellType'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Generic-Spreadsheet'!

!GenericCell commentStamp: 'SauravBhattacharya 7/17/2012 09:36' prior: 0!
A GenericCell is a class for a single cell of a GenericSpreadsheet .

Instance Variables
	cellType:		<Object>
	cellValue:		<Object>

cellType
	- Type of the cell of the following:
		1) String
		2) Numeric
		3) Date

cellValue
	- Value displayed by the cell.
!

!GenericCell methodsFor: 'accessing' stamp: 'SauravBhattacharya 7/16/2012 07:27'!
cellType
	^cellType .! !

!GenericCell methodsFor: 'accessing' stamp: 'SauravBhattacharya 7/16/2012 07:27'!
cellType:aCellType
	cellType := aCellType .! !

!GenericCell methodsFor: 'accessing' stamp: 'SauravBhattacharya 7/16/2012 07:24'!
cellValue
	^cellValue! !

!GenericCell methodsFor: 'accessing' stamp: 'SauravBhattacharya 7/16/2012 07:25'!
cellValue:aCellValue
	cellValue:= aCellValue .! !

!GenericCell methodsFor: 'initialize-release' stamp: 'SauravBhattacharya 7/16/2012 08:20'!
initialize 
	super initialize.
	cellValue:= '_'.
	cellType:= 'string'. "string/numeric/dates"! !

Object subclass: #GenericSpreadsheet
	instanceVariableNames: 'spreadsheetTitle aCollectionOfWorksheets'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Generic-Spreadsheet'!

!GenericSpreadsheet commentStamp: 'SauravBhattacharya 7/17/2012 09:42' prior: 0!
Class intention
	I am GenericSpreadsheet class, for Spreadsheet support in Pharo Smalltalk.

Class collaborations
	Yuriy Mironenko and Carla Florencia.!

!GenericSpreadsheet methodsFor: 'adding' stamp: 'SauravBhattacharya 7/18/2012 05:05'!
addNewWorksheetWithTitle: aTitle

	aCollectionOfWorksheets  add: GenericWorksheet new .	
	(aCollectionOfWorksheets at: aCollectionOfWorksheets size ) worksheetTitle: aTitle .! !

!GenericSpreadsheet methodsFor: 'initialize-release' stamp: 'SauravBhattacharya 7/18/2012 05:02'!
initialize 
	super initialize .
	spreadsheetTitle := 'Default Spreadsheet Title'.
	aCollectionOfWorksheets := OrderedCollection new.
	aCollectionOfWorksheets add: GenericWorksheet new.! !

!GenericSpreadsheet methodsFor: 'accessing' stamp: 'SauravBhattacharya 7/18/2012 05:07'!
numberOfWorksheets
	^aCollectionOfWorksheets size.! !

!GenericSpreadsheet methodsFor: 'accessing' stamp: 'SauravBhattacharya 7/16/2012 07:08'!
spreadsheetTitle
	^spreadsheetTitle.! !

!GenericSpreadsheet methodsFor: 'accessing' stamp: 'SauravBhattacharya 7/16/2012 07:04'!
spreadsheetTitle: aByteString 
	spreadsheetTitle:= aByteString .! !

!GenericSpreadsheet methodsFor: 'accessing' stamp: 'SauravBhattacharya 7/16/2012 07:08'!
worksheetWithIndex: anIndex
	^ aCollectionOfWorksheets at: anIndex.! !

Object subclass: #GenericWorksheet
	instanceVariableNames: 'maxNumOfRows maxNumOfColumns worksheetCells worksheetTitle'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Generic-Spreadsheet'!

!GenericWorksheet commentStamp: 'SauravBhattacharya 7/17/2012 09:38' prior: 0!
A GenericWorksheet is a class for a single worksheet of a GenericSpreadsheet.

Instance Variables
	maxNumOfColumns:		<Object>
	maxNumOfRows:		<Object>
	myWorksheet:		<Object>
	worksheetTitle:		<Object>

maxNumOfColumns
	- Allowed columns in the worksheet.
	
maxNumOfRows
	- Allowed rows in the worksheet.

myWorksheet
	- Collection of cells in the Dictionary data structure

worksheetTitle
	- Title of  the worksheet.
!

!GenericWorksheet methodsFor: 'adding' stamp: 'SauravBhattacharya 7/18/2012 05:09'!
addNewCellWithRowIndex: i columnIndex: j 

	| aCell aPoint |
	aCell:= GenericCell new.
	aPoint := Point new.
	"aPoint setX:i setY:j."
	aPoint := i@j.
	worksheetCells at:aPoint put:aCell.! !

!GenericWorksheet methodsFor: 'accessing' stamp: 'SauravBhattacharya 7/18/2012 05:09'!
cellWithRowIndex:row columnIndex:column

	| anXandY |
	anXandY:= (row@column).
	^worksheetCells  at:anXandY .
	! !

!GenericWorksheet methodsFor: 'initialize-release' stamp: 'SauravBhattacharya 7/18/2012 05:10'!
initialize 
	"Worksheet of size 20*10 is generated"

	super initialize.
	worksheetCells  := Dictionary new.
	worksheetTitle:= 'Default Worksheet Title'.
	maxNumOfColumns := 10.
	maxNumOfRows :=20.
	1 to: maxNumOfRows do: [:row|
		1to: maxNumOfColumns do:[:col|
			self addNewCellWithRowIndex: row columnIndex: col.
		].
	].
	! !

!GenericWorksheet methodsFor: 'accessing' stamp: 'SauravBhattacharya 7/16/2012 07:18'!
maxNumOfColumns
	^maxNumOfColumns.! !

!GenericWorksheet methodsFor: 'accessing' stamp: 'SauravBhattacharya 5/21/2012 20:24'!
maxNumOfColumns: aSmallInteger 
	maxNumOfColumns:= aSmallInteger .! !

!GenericWorksheet methodsFor: 'accessing' stamp: 'SauravBhattacharya 7/16/2012 07:18'!
maxNumOfRows
	^maxNumOfRows.! !

!GenericWorksheet methodsFor: 'accessing' stamp: 'SauravBhattacharya 5/21/2012 20:24'!
maxNumOfRows: aSmallInteger 
	maxNumOfRows:=aSmallInteger .! !

!GenericWorksheet methodsFor: 'accessing' stamp: 'SauravBhattacharya 7/16/2012 07:30'!
worksheetTitle
	^worksheetTitle.! !

!GenericWorksheet methodsFor: 'accessing' stamp: 'SauravBhattacharya 7/16/2012 07:01'!
worksheetTitle: aByteString 
	worksheetTitle:= aByteString .! !
